@@ -290,8 +290,26 @@ binomial_maee <- function(y, X, id, Z, link, maxiter, epsilon, printrange,
         psd_vmin <- is_pos_def(v_min_omega)
 
         if (psd_vmin == 1) {
+          v_result <- ginv_scaleup(v_min_omega)
+          
+          # --- ADD DEFENSIVE CHECKS HERE ---
+          if (!is.numeric(beta_work_cov) || !is.matrix(beta_work_cov)) {
+            stop("Failed to calculate beta_work_cov: it is not a numeric matrix.")
+          }
+          
+          if (!is.numeric(v_result) || !is.matrix(v_result)) {
+            stop("Failed to calculate ginv_scaleup(v_min_omega): it is not a numeric matrix.")
+          }
+          
+          # You might also check dimensions
+          if (ncol(beta_work_cov) != nrow(v_result)) {
+            stop(paste("Matrix dimension mismatch:", 
+                       ncol(beta_work_cov), "vs", nrow(v_result)))
+          }
+          
+    
           Ci <- diag(inv_square_var) %*% (beta_work_cov %*% 
-                  ginv_scaleup(v_min_omega)) %*% diag(square_var)
+                  v_result) %*% diag(square_var)
           Rx <- (y_c - mu_c) * inv_square_var
           Gi <- tcrossprod(Rx)
         } else {
@@ -617,8 +635,27 @@ binomial_maee <- function(y, X, id, Z, link, maxiter, epsilon, printrange,
         psd_vmin <- is_pos_def(v_min_omega)
 
         if (psd_vmin == 1) {
-          Ci <- diag(inv_square_var) %*% (beta_work_cov %*%
-            ginv_scaleup(v_min_omega)) %*% diag(square_var)
+          
+          v_result <- ginv_scaleup(v_min_omega)
+          
+          # --- ADD DEFENSIVE CHECKS HERE ---
+          if (!is.numeric(beta_work_cov) || !is.matrix(beta_work_cov)) {
+            stop("Failed to calculate beta_work_cov: it is not a numeric matrix.")
+          }
+          
+          if (!is.numeric(v_result) || !is.matrix(v_result)) {
+            stop("Failed to calculate ginv_scaleup(v_min_omega): it is not a numeric matrix.")
+          }
+          
+          # You might also check dimensions
+          if (ncol(beta_work_cov) != nrow(v_result)) {
+            stop(paste("Matrix dimension mismatch:", 
+                       ncol(beta_work_cov), "vs", nrow(v_result)))
+          }
+          
+          
+          Ci <- diag(inv_square_var) %*% (beta_work_cov %*% 
+                                            v_result) %*% diag(square_var)
           Rx <- (y_c - mu_c) * inv_square_var
           Gi <- tcrossprod(Rx)
         } else {
